@@ -2,18 +2,20 @@
 #
 # SPDX-License-Identifier: MPL-2.0
 
-from typing import List, Type
+import inspect
 from abc import abstractmethod
 from importlib import import_module
+from typing import List, Type
+
 import pandas as pd
-import inspect
-from openstef.model.regressors.regressor import OpenstfRegressor
+
 from openstef.model.objective import (
-    RegressorObjective,
+    EVAL_METRIC,
     TEST_FRACTION,
     VALIDATION_FRACTION,
-    EVAL_METRIC,
+    RegressorObjective,
 )
+from openstef.model.regressors.regressor import OpenstfRegressor
 
 
 class CustomOpenstfRegressor(OpenstfRegressor):
@@ -41,7 +43,8 @@ def load_custom_model(custom_model_path) -> CustomOpenstfRegressor:
         or not issubclass(model_class, CustomOpenstfRegressor)
     ):
         raise ValueError(
-            f"The path {custom_model_path!r} does not correspond to a concrete CustomOpenstfRegressor subclass"
+            f"The path {custom_model_path!r} does not correspond to a concrete"
+            " CustomOpenstfRegressor subclass"
         )
 
     return model_class
